@@ -22,6 +22,7 @@ from PyQt5.QtCore import pyqtSignal
 from PyQt5.QtCore import QPoint
 from PyQt5.QtCore import QByteArray
 
+from medlib.handle_property import getConfigIni
 from pkg_resources import resource_filename
 from math import copysign
 from cardholder.card_data_interface import CardDataInterface
@@ -115,11 +116,11 @@ class CardHolder( QWidget ):
         self.setFocusPolicy(Qt.StrongFocus)
         self.setFocus()      
     
-    def setSelectedRootCardIndex(self, selected_root_card_index):
-        self.selected_root_card_index = selected_root_card_index
-        
-    def getSelectedRootCardIndex(self):
-        return self.selected_root_card_index        
+#    def setSelectedRootCardIndex(self, selected_root_card_index):
+#        self.selected_root_card_index = selected_root_card_index
+#        
+#    def getSelectedRootCardIndex(self):
+#        return self.selected_root_card_index        
     
     def set_y_coordinate_by_reverse_index_method(self, method):
         self.get_y_coordinate_by_reverse_index_method = method
@@ -186,7 +187,6 @@ class CardHolder( QWidget ):
     def stop_spinner(self):
         self.collecting_spinner.setHidden(True)
         self.spinner_movie.stop()
-
         
     # ---------------------------------------------------------------------
     #
@@ -195,7 +195,6 @@ class CardHolder( QWidget ):
     # this method should be called when you want a new collection of cards
     #
     # ---------------------------------------------------------------------
-#    def startCardCollection(self, parameters):
     def startCardCollection(self):        
 
         self.start_spinner()
@@ -586,11 +585,48 @@ class CardHolder( QWidget ):
     def wheelEvent(self, event):
         modifiers = QApplication.keyboardModifiers()
         value = event.angleDelta().y()/8/15   # in normal case it is +1 or -1
-        self.rolling_wheel(-value)
+
+        if modifiers == Qt.ControlModifier:
+            
+            # Change SCALE_LEVEL
+            config_ini_function = getConfigIni()
+            scale_level = int(config_ini_function.getScaleLevel())
+            scale_level = scale_level + (1 if value > 0 else - 1)
+            config_ini_function.setScaleLevel(str(scale_level))
+            
+            index_of_focused_card = self.getFocusedCard().getIndexInDataList()
+            self.focus_index(index_of_focused_card)
+            
+        else:
+            self.rolling_wheel(-value)
   
     def keyPressEvent(self, event):
+
+        if event.key() == QtCore.Qt.Key_Up and event.modifiers() == Qt.ControlModifier:
+            
+            # Change SCALE_LEVEL
+            config_ini_function = getConfigIni()
+            scale_level = int(config_ini_function.getScaleLevel())
+            scale_level = scale_level + 1
+            config_ini_function.setScaleLevel(str(scale_level))
+
+            parent_collector = self.getParentCollector()
+            index_of_focused_card = self.getFocusedCard().getIndexInDataList()
+            self.focus_index(index_of_focused_card)
+            
+        elif event.key() == QtCore.Qt.Key_Down and event.modifiers() == Qt.ControlModifier:
+            
+            # Change SCALE_LEVEL
+            config_ini_function = getConfigIni()
+            scale_level = int(config_ini_function.getScaleLevel())
+            scale_level = scale_level - 1
+            config_ini_function.setScaleLevel(str(scale_level))
+            
+            parent_collector = self.getParentCollector()
+            index_of_focused_card = self.getFocusedCard().getIndexInDataList()
+            self.focus_index(index_of_focused_card)            
         
-        if event.key() == QtCore.Qt.Key_Up:
+        elif event.key() == QtCore.Qt.Key_Up:
             self.animated_move_to_next(sleep=0.04)
             
         elif event.key() == QtCore.Qt.Key_Down:
@@ -677,14 +713,12 @@ class CardHolder( QWidget ):
     def refresh(self, parent_collector=None, index=0):
         """
         Fills up the CardHolder with Cards and pulls the <index>th Card to front
+        
+        
         """
        
         if parent_collector:
 
-#            # Listener of the refresh list
-#            # Here you refresh the self.mediaCollector object in the medlib_gui
-#            self.refresh_list_listener(parent_collector)            
-        
             # Without hierarchy
             if not self.parent.isSwitchKeepHierarchy():
                 sum_list = self.collectMediaStorageWithoutHierarchy([], parent_collector)
@@ -701,11 +735,12 @@ class CardHolder( QWidget ):
                 sum_list = mcl + msl
 
                 # Listener of the refresh list
-                # Here you refresh the self.mediaCollector object in the medlib_gui
+                # 1. set self.mediaCollector
+                # 2. fill up the "play continously" list if there is NO ongoing play
+                # 3. save the "play continously" list if there IS ongoing play
                 self.refresh_list_listener(parent_collector, msl)            
 
             self.fill_up_card_descriptor_list(sum_list)                
-#            self.focus_index(parent_collector.getIndex())
             self.focus_index(index)
 
         self.stop_spinner()
@@ -892,16 +927,6 @@ class Card(QWidget):
         
         self.setAttribute(Qt.WA_StyledBackground, True)        
 
-#    def getParentCard(self):
-#        card_data_collector = self.card_data.getParentCollector()
-#        return card_data_collector.getCard()
-        
-#    def setSelectedChildCardIndex(self, index):
-#        self.selected_child_card_index = index
-#        
-#    def getSelectedChildCardIndex(self):
-#        return self.selected_child_card_index
-        
     def setIndexInDataList(self, index):
         self.index = index
         
@@ -1025,6 +1050,11 @@ class Card(QWidget):
     #
     # ----------------------------------------
     def resized(self, width, height, local_index=None):
+        """
+        Input:
+            width:    CardHolder width
+            height:   CardHolder height
+        """
         # The farther the card is the narrower it is
         if local_index==None:
             local_index = self.local_index
@@ -1041,7 +1071,7 @@ class Card(QWidget):
     # ---------------------------------------
     def place(self, local_index, front_remove=False):
         
-        # Need to resize and reposition the Car as 'The farther the card is the narrower it is'
+        # Need to resize and reposition the Card as 'The farther the card is the narrower it is'
         self.resized(self.card_holder.width(), self.card_holder.height(), local_index)
         x_coordinate = self.card_holder.get_border_width() + self.card_holder.get_x_offset_by_index_method(local_index)
         y_coordinate = self.card_holder.get_border_width() + self.get_y_coordinate(local_index)
