@@ -330,7 +330,7 @@ class ControlButtonsHolder(QWidget):
     # Image/Appendix CLICK button
     #
     # =================================================
-    def image_or_appendix_on_click(self, list_to_play, index):
+    def image_or_appendix_on_click(self, list_to_play):
         
 #        self.control_panel.gui.refreshPlayContinouslyListBeforeStartPlaying(index)
 #        print("Disabled Play, Enabled Stop and selected Index:", index)
@@ -401,7 +401,6 @@ class ControlButtonsHolder(QWidget):
         in the Play list according to the index. 
         This method is called from the PlayerThread object when the next media is started
         """
-        #self.enablePlayContinously(False)
         self.select_play_continously_element_by_index(index)  
         self.control_panel.gui.refreshPlayContinouslyListBeforeStartPlaying(index)
 
