@@ -22,7 +22,7 @@ from PyQt5.QtWidgets import QDesktopWidget
 from PyQt5.QtCore import Qt
 
 from medlib.constants import MAIN_BACKGROUND_COLOR, LINK_TILE_FONT_SIZE,\
-    CONTROL_BACKGROUND_COLOR
+    CONTROL_BACKGROUND_COLOR, PANEL_HEIGHT
 from medlib.constants import CARD_BORDER_FOCUSED_BACKGROUND_COLOR
 from medlib.constants import CARD_BORDER_NORMAL_BACKGROUND_COLOR
 from medlib.constants import COLLECTOR_BACKGROUND_COLOR
@@ -239,8 +239,6 @@ class MedlibGui(QWidget):#, QObject):
         
         self.refreshPlayContinouslyListAfterRefresh()
         
-        
-        
     def refreshPlayContinouslyListAfterRefresh(self, forced=False):            
         
         # The Play Continously list should NOT be refreshed
@@ -268,20 +266,18 @@ class MedlibGui(QWidget):#, QObject):
                 
                 # Disable the start and stop buttons
                 self.control_panel.disablePlayStopContinously()
-
- 
- 
  
     def refreshPlayContinouslyListBeforeStartPlaying(self, index=0):            
         
         self.control_panel.enablePlayContinously(False)
 
-        # Clear the Play Continously List
-        self.control_panel.clear_play_continously_elements()
-
-        # Fill up the Play Contionously List - Dropdown 
-        for media in self.actualSortedStorageList:
-            self.control_panel.add_play_continously_element(media.getFormattedTitle(), media.getPathOfMedia(), media.getTypeOfMedia())
+#
+#        # Clear the Play Continously List
+#        self.control_panel.clear_play_continously_elements()
+#
+#        # Fill up the Play Contionously List - Dropdown 
+#        for media in self.actualSortedStorageList:
+#            self.control_panel.add_play_continously_element(media.getFormattedTitle(), media.getPathOfMedia(), media.getTypeOfMedia())
 
         self.control_panel.control_buttons_holder.select_play_continously_element_by_index(index)
  
@@ -347,17 +343,18 @@ class MedlibGui(QWidget):#, QObject):
         card.setBorderRadius(10)
         card.setBorderWidth(8)
         
-        card.setMaximumHeight(300)
-        card.setMinimumHeight(300)
-
         card.setNotFocused()
  
         panel = card.getPanel()
         layout = panel.getLayout()
         
-#        config_ini = getConfigIni()
-#        config_ini.getScale()
-        myPanel = card.card_data.getWidget(1)
+        # read the actual SCALE
+        reReadConfigIni()
+        scale_factor = float(config_ini['scale_factor'])
+        scale_level = int(config_ini['scale_level'])
+        scale = float( 1 + scale_level * scale_factor )
+
+        myPanel = card.card_data.getWidget(scale)
 
         layout.addWidget(myPanel)
         
@@ -372,15 +369,8 @@ class MedlibGui(QWidget):#, QObject):
     def goesDeeper(self, mediaCollector):
         self.card_holder.goesDeeper(mediaCollector)
                       
-#        mcl = mediaCollector.getMediaCollectorList()
-#        msl = mediaCollector.getMediaStorageList()
-#        sum_list = mcl + msl
-#        if sum_list:
-#            self.card_holder.refresh(sum_list)    
-
     def goesHigher(self):
-        self.card_holder.goesHigher()
-        
+        self.card_holder.goesHigher()        
         
     def changeKeepHierarchy(self, keep):
         """
@@ -398,10 +388,6 @@ class MedlibGui(QWidget):#, QObject):
         reReadConfigIni()
         self.card_holder.refresh(self.mediaCollector)
        
-#    def to_integer(self, value):         
-#        hours, minutes = map(int, (['0']+value.split(':'))[-2:])
-#        return hours * 60 + minutes
-  
     def resizeEvent(self, event):
         """
         When the window resized, then the Hierarchy Title will be re-arranged.
@@ -415,22 +401,7 @@ class MedlibGui(QWidget):#, QObject):
         self.card_holder.alignSpinner(self.geometry().width(), self.geometry().height())
   
   
-  
-  
-
-  
-  
-  
-  
-  
-  
-  
-  
-  
-  
-  
-  
-  
+ 
   
   
   
@@ -463,7 +434,7 @@ class LinkLabel(QLabel):
 
     # Mouse Press
     def mousePressEvent(self, event):
-        if event.buttons() == Qt.LeftButton: # and self.index:
+        if event.buttons() == Qt.LeftButton and self.index is not None:
             QApplication.restoreOverrideCursor()
 
             # Generate new Hierarchy Title        
@@ -545,21 +516,23 @@ class HierarchyTitle(QWidget):
     
     def setTitle(self, collector):
         clearLayout(self.text_layout)
-        self.title_list = []
-        
+
         #One element in the title_list:
         #    "title"
         #    "collector"
         #    "card-list"
-        #    "index"    
+        #    "index"
+        self.title_list = []
+        
         collector.getFormattedTitleList(self.title_list)
 
         one_line_container, one_line_container_layout = self.get_one_line_container()
                 
         text_width = 0
         self.lines = 1
+        
+        # Title with link function
         for title in reversed(self.title_list[1:]):
-#        for title in reversed(title_list):
             
             # Generate text
             label = LinkLabel(self.parent, title["title"], title["collector"], title["card-list"], title["index"])            
@@ -587,7 +560,7 @@ class HierarchyTitle(QWidget):
 
             one_line_container_layout.addWidget(label)
        
-       
+        # The last title (right) which has NO link function
         label = LinkLabel(self.parent, self.title_list[0]["title"], self.title_list[0]["collector"], self.title_list[0]["card-list"], self.title_list[0]["index"])
         text_width = text_width + self.get_width_in_pixels(label)
         if text_width > self.text_holder.size().width():
@@ -614,20 +587,6 @@ class HierarchyTitle(QWidget):
         one_line_container_layout.setAlignment(Qt.AlignHCenter)
         return one_line_container, one_line_container_layout
 
-#    def create_one_line_container(self):
-#        self.one_line_container = QWidget(self)
-#        self.one_line_container_layout = QHBoxLayout(self.one_line_container)
-#        self.one_line_container_layout.setContentsMargins(0, 0, 0, 0)
-#        self.one_line_container_layout.setSpacing(0)
-#        self.one_line_container.setLayout(self.one_line_container_layout)
-#        self.one_line_container_layout.setAlignment(Qt.AlignHCenter)
-
-#    def add_to_one_line_container(self, cw):
-#        self.one_line_container_layout.addWidget(cw)
-        
-#    def push_new_line_container(self):
-#        self.text_layout.addWidget(self.one_line_container)
-        
     def getOneLevelHigher(self):
         if len(self.title_list) >= 2:
             return (self.title_list[1]["collector"], self.title_list[1]["index"])
